@@ -1,8 +1,9 @@
 __all__ = [
-    'B','Blank','C','choose','common','crop_from_bb','cv2','diff','find',
+    'B','Blank','C','choose','common','crop_from_bb','diff','find',
     'flatten','fname','find','fname2','glob','Glob','Image','inspect','jitter', 'L', 'lzip',
     'line','lines',
     'dumpdill','loaddill',
+    'to_absolute', 'to_relative',
     'logger','extn', 'makedir', 'np', 'now','nunique','os','pad','pd','pdfilter','parent','Path','pdb',
     'plt','PIL','puttext','randint','rand','re','read','readPIL','rect','rename_batch','resize','rotate','see',
     'set_logging_level','show','store_attr','stem','stems','subplots','sys','tqdm','Tqdm','trange','Timer','unique','uint','write',
@@ -13,7 +14,7 @@ __all__ = [
     'Info','Warn','Debug','Excep'
 ]
 
-import cv2, glob, numpy as np, pandas as pd, tqdm, os, sys, re
+import glob, numpy as np, pandas as pd, tqdm, os, sys, re
 import PIL
 from PIL import Image
 try:
@@ -45,6 +46,11 @@ Warn  = lambda x: logger.warning(x)
 Debug = lambda x: logger.debug(x)
 Excep = lambda x: logger.exception(x)
 
+try:
+    import cv2
+    __all__ += ['cv2']
+except: logger.warning('Skipping cv2 import')
+
 import time
 class Timer:
     def __init__(self, N):
@@ -586,3 +592,26 @@ def write(image, fpath):
     cv2.imwrite(fpath, image)
 
 def lzip(*x): return list(zip(*x))
+
+def to_absolute(df, shape):
+    if isinstance(shape, np.ndarray) and shape.ndim >=2:
+        shape = shape.shape[:2]
+    h, w = shape
+    df = df.copy()
+    def _round(x): return np.round(x.values.astype(np.double)).astype(np.uint16)
+    df['x'] = _round(df.x*w)
+    df['X'] = _round(df.X*w)
+    df['y'] = _round(df.y*h)
+    df['Y'] = _round(df.Y*h)
+    return df
+
+def to_relative(df, shape):
+    if isinstance(shape, np.ndarray) and shape.ndim >=2:
+        shape = shape.shape[:2]
+    h, w = shape
+    df = df.copy()
+    df['x'] = (df.x / w)
+    df['X'] = (df.X / w)
+    df['y'] = (df.y / h)
+    df['Y'] = (df.Y / h)
+    return df
